%define major		4
%define libname		%mklibname %{name}_ %{major}
%define develname	%mklibname %{name} -d

Name:		blosc2
Version:	2.15.2
Release:	%mkrel 1
Summary:	High performance compressor optimized for binary data
Group:		System/Libraries
License:	BSD-3-Clause
URL:		https://www.blosc.org/
Source0:	https://github.com/Blosc/c-blosc2/archive/v%{version}/c-blosc2-%{version}.tar.gz

BuildRequires:	cmake
BuildRequires:	ninja-build
BuildRequires:	pkgconfig(liblz4)
BuildRequires:	pkgconfig(libxxhash)
BuildRequires:	pkgconfig(libzstd)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(zlib-ng)

%description
Blosc is a high performance compressor optimized for binary data
(i.e. floating-point numbers, integers, and booleans, although it can handle
string data too). It has been designed to transmit data to the processor cache
faster than the traditional, non-compressed, direct memory fetch approach via a
memcpy() OS call. Blosc main goal is not just to reduce the size of large
datasets on-disk or in-memory, but also to accelerate memory-bound computations.

C-Blosc2 is the new major version of C-Blosc, and is backward compatible with
both the C-Blosc1 API and its in-memory format. However, the reverse thing is
generally not true for the format; buffers generated with C-Blosc2 are not
format-compatible with C-Blosc1.

%package -n	%{libname}
Summary:	A blocking, shuffling and lossless compression library
Group:		System/Libraries

%description -n	%{libname}
Blosc is a metacompressor (using actual algorithms like BloscLZ, LZ4,
LZ4HC, Snappy or Zlib) for binary data, with a focus on reducing
memory bus activity.

%package -n	%{develname}
Summary:	Development files for %{name}
Group:		Development/C++
Requires:	%{libname} >= %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{develname}
The %{develname} package contains libraries and header files for developing
applications that use %{name}.

%prep
%autosetup -n c-blosc2-%{version} -p1

# https://github.com/Blosc/c-blosc2/issues/489
rm plugins/codecs/ndlz/xxhash.?
sed -r -i '/xxhash.c/d' plugins/codecs/ndlz/CMakeLists.txt

# let's do this to make it clear that we're not using those
rm -r internal-complibs/* internal-complibs

%build
%cmake  -GNinja \
	-DBUILD_STATIC:BOOL=OFF \
	-DBUILD_FUZZERS:BOOL=OFF \
	-DPREFER_EXTERNAL_LZ4:BOOL=ON \
	-DPREFER_EXTERNAL_ZLIB:BOOL=ON \
	-DPREFER_EXTERNAL_ZSTD:BOOL=ON \
	-DDEACTIVATE_AVX2:BOOL=ON \
	-DCMAKE_C_FLAGS:STRING="%{optflags} -Wno-unused-variable"
        # We need to pass the distro build flags here, otherwise they are ignored.
        # Silence warnings about stupid programming errors.
%cmake_build

%install
%cmake_install

%check
# Tests fail with -j12: https://github.com/Blosc/c-blosc2/issues/432
%ctest -j1

%files -n %{libname}
%doc ANNOUNCE.* README* RELEASE_NOTES.* THANKS.* ROADMAP.rst FAQ.*
%license LICENSE.txt
%{_libdir}/libblosc2.so.%{major}
%{_libdir}/libblosc2.so.%{version}

%files -n %{develname}
%doc README.rst
%{_includedir}/b2nd.h
%{_includedir}/blosc2.h
%{_includedir}/%{name}/
%{_libdir}/libblosc2.so
%{_libdir}/pkgconfig/blosc2.pc
%{_libdir}/cmake/Blosc2/


%changelog
* Mon Jan 06 2025 daviddavid <daviddavid> 2.15.2-1.mga10
+ Revision: 2135713
- new version: 2.15.2

* Sat Aug 03 2024 daviddavid <daviddavid> 2.15.1-1.mga10
+ Revision: 2083491
- new version: 2.15.1

* Tue Jul 23 2024 daviddavid <daviddavid> 2.15.0-1.mga10
+ Revision: 2082343
- new version: 2.15.0
- now libmajor is 4

* Sun Apr 21 2024 daviddavid <daviddavid> 2.14.4-1.mga10
+ Revision: 2060232
- new version: 2.14.4

* Tue Apr 09 2024 daviddavid <daviddavid> 2.14.0-1.mga10
+ Revision: 2056113
- new version: 2.14.0

* Sat Feb 24 2024 daviddavid <daviddavid> 2.13.2-1.mga10
+ Revision: 2043820
- new version: 2.13.2
- initial package blosc2

* Tue Sep 19 2023 daviddavid <daviddavid> 1.21.5-1.mga10
+ Revision: 1987997
- new version: 1.21.5

* Mon Aug 28 2023 daviddavid <daviddavid> 1.21.4-1.mga10
+ Revision: 1980326
- new version: 1.21.4

* Tue Jan 03 2023 daviddavid <daviddavid> 1.21.2-1.mga9
+ Revision: 1929695
- new version: 1.21.2

* Sat Sep 10 2022 neoclust <neoclust> 1.21.1-1.mga9
+ Revision: 1886617
- New version 1.21.1

* Wed Mar 30 2022 umeabot <umeabot> 1.21.0-2.mga9
+ Revision: 1834124
- Mageia 9 Mass Rebuild

* Thu Dec 24 2020 daviddavid <daviddavid> 1.21.0-1.mga8
+ Revision: 1663412
- new version: 1.21.0

* Fri Sep 11 2020 daviddavid <daviddavid> 1.20.1-1.mga8
+ Revision: 1624641
- new version: 1.20.1

* Sun Aug 02 2020 daviddavid <daviddavid> 1.20.0-1.mga8
+ Revision: 1610560
- new version: 1.20.0

* Sat Jun 06 2020 daviddavid <daviddavid> 1.19.0-1.mga8
+ Revision: 1590717
- new version: 1.19.0

* Tue Mar 31 2020 daviddavid <daviddavid> 1.18.1-1.mga8
+ Revision: 1562567
- new version: 1.18.1

* Tue Feb 18 2020 umeabot <umeabot> 1.17.1-2.mga8
+ Revision: 1541257
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Sun Dec 22 2019 daviddavid <daviddavid> 1.17.1-1.mga8
+ Revision: 1469432
- new version: 1.17.1

* Fri Jul 26 2019 daviddavid <daviddavid> 1.17.0-1.mga8
+ Revision: 1424191
- new version: 1.17.0

* Mon Mar 11 2019 daviddavid <daviddavid> 1.16.3-1.mga7
+ Revision: 1373919
- new version: 1.16.3

* Mon Feb 04 2019 daviddavid <daviddavid> 1.16.2-1.mga7
+ Revision: 1363129
- new version: 1.16.2

* Fri Jan 04 2019 daviddavid <daviddavid> 1.15.1-1.mga7
+ Revision: 1348995
- new version: 1.15.1

* Sun Dec 02 2018 daviddavid <daviddavid> 1.15.0-1.mga7
+ Revision: 1337615
- new version: 1.15.0

* Fri Sep 21 2018 umeabot <umeabot> 1.14.4-2.mga7
+ Revision: 1295546
- Mageia 7 Mass Rebuild

* Fri Aug 03 2018 daviddavid <daviddavid> 1.14.4-1.mga7
+ Revision: 1246989
- new version: 1.14.4

* Mon Apr 09 2018 daviddavid <daviddavid> 1.14.3-1.mga7
+ Revision: 1216400
- new version: 1.14.3

* Sat Mar 24 2018 daviddavid <daviddavid> 1.14.2-1.mga7
+ Revision: 1211833
- initial package blosc

